@@ -4,7 +4,7 @@ use warnings;
 
 use base 'Test2::Compare::Base';
 
-our $VERSION = '0.000051';
+our $VERSION = '0.000053';
 
 use Test2::Util::HashBase qw/ending items/;
 
@@ -58,33 +58,30 @@ sub deltas {
 
         my $check = $convert->($item);
 
-        my @item_deltas;
+        my $match = 0;
         for my $idx (0..$#list) {
             my $val = $list[$idx];
-            my @this_deltas = $check->run(
+            my $deltas = $check->run(
                 id      => [ARRAY => $idx],
                 convert => $convert,
                 seen    => $seen,
                 exists  => 1,
                 got     => $val,
             );
-            if (@this_deltas) {
-                push @item_deltas,@this_deltas;
-            }
-            else {
-                @item_deltas = ();
+
+            unless ($deltas) {
+                $match++;
                 delete $unmatched{$idx};
                 last;
             }
         }
-        if (@item_deltas) {
-            push @deltas, $self->delta_class->new(
+        unless ($match) {
+            push @deltas => $self->delta_class->new(
                 dne      => 'got',
-                verified => 1,
+                verified => undef,
                 id       => [ARRAY => '*'],
                 got      => undef,
                 check    => $check,
-                children => \@item_deltas,
             );
         }
     }
